LastUpdateState class

Implementers

Constructors

LastUpdateState({required UpdateStateEnum state, required String? message, int? targetVersion})

Properties

hashCode int
The hash code for this object.
no setterinherited
message String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state UpdateStateEnum
final
targetVersion int?
targetVersion is the version code of app new version
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited