LastUpdateStateModel class
- Inheritance
-
- Object
- LastUpdateState
- LastUpdateStateModel
Constructors
- LastUpdateStateModel({required UpdateStateEnum state, required String? message})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → UpdateStateEnum
-
finalinherited
- targetVersion → int?
-
targetVersion is the version code of app new version
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromMapToEntity(
Map< Object?, Object?> ? mapObject) → LastUpdateState